@@ -75,6 +75,7 @@ func (a Apply) Run() error {
 		&phase.InstallWorkers{},
 		&phase.UpgradeControllers{},
 		&phase.UpgradeWorkers{NoDrain: a.NoDrain},
+		&phase.Reinstall{},
 		&phase.ResetWorkers{NoDrain: a.NoDrain},
 		&phase.ResetControllers{NoDrain: a.NoDrain},
 		&phase.RunHooks{Stage: "after", Action: "apply"},
@@ -108,7 +109,7 @@ func (a Apply) Run() error {
 
 	duration := time.Since(start).Truncate(time.Second)
 	text := fmt.Sprintf("==> Finished in %s", duration)
-	log.Infof(phase.Colorize.Green(text).String())
+	log.Info(phase.Colorize.Green(text).String())
 
 	for _, host := range a.Manager.Config.Spec.Hosts {
 		if host.Reset {
@@ -141,8 +142,8 @@ func (a Apply) Run() error {
 			cmd.WriteString(a.ConfigPath)
 		}
 
-		log.Infof("Tip: To access the cluster you can now fetch the admin kubeconfig using:")
-		log.Infof("     " + phase.Colorize.Cyan(cmd.String()).String())
+		log.Info("Tip: To access the cluster you can now fetch the admin kubeconfig using:")
+		log.Info("     " + phase.Colorize.Cyan(cmd.String()).String())
 	}
 
 	return nil
