@@ -168,10 +168,10 @@ func (l *Linux) DownloadURL(h os.Host, url, destination string, opts ...exec.Opt
 }
 
 // DownloadK0s performs k0s binary download from github on the host
-func (l *Linux) DownloadK0s(h os.Host, path string, version *version.Version, arch string) error {
+func (l *Linux) DownloadK0s(h os.Host, path string, version *version.Version, arch string, opts ...exec.Option) error {
 	v := strings.ReplaceAll(strings.TrimPrefix(version.String(), "v"), "+", "%2B")
 	url := fmt.Sprintf("https://github.com/k0sproject/k0s/releases/download/v%[1]s/k0s-v%[1]s-%[2]s", v, arch)
-	if err := l.DownloadURL(h, url, path); err != nil {
+	if err := l.DownloadURL(h, url, path, opts...); err != nil {
 		return fmt.Errorf("failed to download k0s - check connectivity and k0s version validity: %w", err)
 	}
 
